@@ -5,34 +5,30 @@ from typing import AsyncIterator
 from thecodecrate_pipeline import Pipeline
 
 
-# Define the stages
+# Define stages
 async def stage1(stream: AsyncIterator[int]) -> AsyncIterator[int]:
     async for item in stream:
         # Multiply each item by 2
         yield item * 2
-        await asyncio.sleep(0.1)  # Simulate processing delay
+        await asyncio.sleep(0.01)  # Simulate processing delay
 
 
 async def stage2(stream: AsyncIterator[int]) -> AsyncIterator[str]:
     async for item in stream:
         # Convert each item to a formatted string
         yield f"Number: {item}"
-        await asyncio.sleep(0.1)
+        await asyncio.sleep(0.01)
 
 
 # Create the pipeline
-pipeline = (
-    Pipeline[AsyncIterator[int], AsyncIterator[str]]()
-    .pipe(stage1)
-    .pipe(stage2)
-)
+pipeline = Pipeline[AsyncIterator[int], AsyncIterator[str]]().pipe(stage1).pipe(stage2)
 
 
 # Define the input stream
 async def input_stream() -> AsyncIterator[int]:
     for i in range(5):
         yield i
-        await asyncio.sleep(0.1)
+        await asyncio.sleep(0.01)
 
 
 @pytest.mark.asyncio
